# 0x Python Wrapper


### API docs
Can be found here: https://0x.org/docs/api

### DEV environment

Install test dependencies: `python3 setup.py install -e [.dev]`
Run some tests: `python3 -m unittest tests.test_0x`
Run all tests: `python3 -m unittest discover -s ./tests`